@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2017-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -21,6 +21,7 @@
 #include "../statusbarprogresswidget.h"
 #include "../progressdialog.h"
 #include "../progressmanager.h"
+#include "kdepimtest_layout.h"
 #include <QTest>
 #include <QHBoxLayout>
 #include <QPushButton>
@@ -43,7 +44,7 @@ void StatusbarProgressWidgetTest::shouldHaveDefaultValue()
     KPIM::StatusbarProgressWidget w(progress, widget);
     QHBoxLayout *boxLayout = w.findChild<QHBoxLayout *>(QStringLiteral("boxLayout"));
     QVERIFY(boxLayout);
-    QCOMPARE(boxLayout->margin(), 0);
+    KdepimTestLayout::checkContentsMargins(0, boxLayout);
     QCOMPARE(boxLayout->spacing(), 0);
 
     QPushButton *mButton = w.findChild<QPushButton *>(QStringLiteral("button"));
